/* -*- C++ -*-
 * 
 * Copyright (c) 1999 Joe Yandle <joe@wlcg.com>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

#include "MsqlResultSet.h"

MsqlResultSet::MsqlResultSet(m_result* qRet)
{
    queryRet = qRet;
    
    if(queryRet) {
	numRow = msqlNumRows(queryRet);
	numCol = msqlNumFields(queryRet);
	curRow = 0;
	
	for(int i=0; i<numCol; i++) {
	    msqlFieldSeek(queryRet, i);
	    m_field* colName = msqlFetchField(queryRet);
	    colVector.push_back( String(colName->name) );
	}
    }
    else {
	numRow = 0;
	numCol = 0;
	curRow = 0;	
    }
}


MsqlResultSet::~MsqlResultSet()
{
    if(queryRet) {
	msqlFreeResult(queryRet);
    }
}

bool MsqlResultSet::next()
{
    if(++curRow > numRow) {
	return false;
    }
    
    char** temp = (char**)msqlFetchRow(queryRet);

    rowVector.clear();
    rowHash.clear();

    for(int i=0; i<numCol; i++) {
	String key = colVector[i];
	String val( temp[i] );
	
	rowVector.push_back(val);
	rowHash.insert( Hashtable::value_type(key, val)  );
    }

    return true;
}

StringVector MsqlResultSet::getVector()
{
    return rowVector;
}

Hashtable MsqlResultSet::getHashtable()
{
    return rowHash;
}

String MsqlResultSet::getString(String colName)
{
    return rowHash[colName];
}

String MsqlResultSet::getString(int colNmbr)
{
    return rowVector[colNmbr];
}

int MsqlResultSet::numRows() 
{
    return numRow;
}

int MsqlResultSet::numCols() 
{
    return numCol;
}
